#!/bin/bash
# 
# Copyright 2009	Luis R. Rodriguez <mcgrof@winlab.rutgers.edu>
#
# Use this to update compat-sound-2.6 to the latest
# linux-2.6.git tree you have.
#
# export GIT_TREE=/home/mcgrof/linux-2.6/
# 
# for example
#
GIT_URL="git://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux-2.6.git"

SOUND_DIRS="sound/core "
SOUND_DIRS="$SOUND_DIRS sound/core/oss"
SOUND_DIRS="$SOUND_DIRS sound/core/seq"
SOUND_DIRS="$SOUND_DIRS sound/core/seq/oss"

# PCI Sound Drivers that have their own directory
SOUND_DRIVERS="sound/pci/hda/"

# From sound/oss/
OSS_FILES="sound_firmware.h"

# User exported this variable
if [ -z $GIT_TREE ]; then
	GIT_TREE="/home/$USER/devel/linux-2.6/"
	if [ ! -d $GIT_TREE ]; then
		echo "Please tell me where your linux-2.6 git tree is."
		echo "You can do this by exporting its location as follows:"
		echo
		echo "  export GIT_TREE=/home/$USER/linux-2.6/"
		echo
		echo "If you do not have one you can clone the repository:"
		echo "  git-clone $GIT_URL"
		exit 1
	fi
else
	echo "You said your linux-2.6 git tree is: $GIT_TREE"
fi

mkdir -p include/sound \
	include/linux/unaligned \
	sound/core \
	sound/oss \
	sound/pci

# include/sound
echo "Copying $GIT_TREE/include/sound/*.h"
cp $GIT_TREE/include/sound/*.h include/sound/

# Sound core
echo "Copying $GIT_TREE/sound/*.[ch]"
cp $GIT_TREE/sound/*.[ch] sound/
cp $GIT_TREE/sound/Makefile sound/
rm -f sound/*.mod.c

echo "Copying $GIT_TREE/pci/Makefile"
cp $GIT_TREE/sound/pci/Makefile sound/pci/

# sound core specific dirs
for i in $SOUND_DIRS; do
	echo "Copying $GIT_TREE/$i/*.[ch]"
	mkdir -p $i
	cp $GIT_TREE/$i/*.[ch] $i/
	cp $GIT_TREE/$i/Makefile $i/
	rm -f $i/*.mod.c
done

# Drivers in their own directory
for i in $SOUND_DRIVERS; do
	mkdir -p $i
	echo "Copying $GIT_TREE/$i/*.[ch]"
	cp $GIT_TREE/$i/*.[ch] $i/
	cp $GIT_TREE/$i/Makefile $i/
	rm -f $i/*.mod.c
done

for i in $OSS_FILES; do
	echo "Copying $GIT_TREE/sound/oss/$i"
	cp $GIT_TREE/sound/oss/$i sound/oss/
done

DIR="include/linux/unaligned"
echo "Copying $GIT_TREE/$DIR/*"
cp $GIT_TREE/$DIR/* $DIR


# Compat stuff
cp compat/compat.c sound/
cp compat/compat.h include/sound/

patch -p1 -N -t < compat/compat.diff
RET=$?
if [[ $RET -ne 0 ]]; then
	echo "Patching compat.diff failed, update it"
	exit $RET
fi
DIR="$PWD"
cd $GIT_TREE && git describe > $DIR/git-describe && cd $DIR
echo "Updated from ${GIT_TREE}, git-describe says:"
cat git-describe
if [ -d ./.git ]; then
	git describe > compat-release
	cd $GIT_TREE && git tag -l| grep master | tail -1 > $DIR/master-tag && cd $DIR
	if [ -f master-tag ]; then
		echo "linux-2.6 latest tag:"
		cat master-tag
	fi
fi
echo "This is compat-release:"
cat compat-release
